# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: text_extract.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='text_extract.proto',
  package='text_extract',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x12text_extract.proto\x12\x0ctext_extract\":\n\x0e\x45xtractRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04html\x18\x03 \x01(\t\"7\n\x0c\x45xtractReply\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t2V\n\rTextExtractor\x12\x45\n\x07\x65xtract\x12\x1c.text_extract.ExtractRequest\x1a\x1a.text_extract.ExtractReply\"\x00\x62\x06proto3')
)




_EXTRACTREQUEST = _descriptor.Descriptor(
  name='ExtractRequest',
  full_name='text_extract.ExtractRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='text_extract.ExtractRequest.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='text_extract.ExtractRequest.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='html', full_name='text_extract.ExtractRequest.html', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=94,
)


_EXTRACTREPLY = _descriptor.Descriptor(
  name='ExtractReply',
  full_name='text_extract.ExtractReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='text_extract.ExtractReply.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='text_extract.ExtractReply.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='text_extract.ExtractReply.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=151,
)

DESCRIPTOR.message_types_by_name['ExtractRequest'] = _EXTRACTREQUEST
DESCRIPTOR.message_types_by_name['ExtractReply'] = _EXTRACTREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtractRequest = _reflection.GeneratedProtocolMessageType('ExtractRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXTRACTREQUEST,
  __module__ = 'text_extract_pb2'
  # @@protoc_insertion_point(class_scope:text_extract.ExtractRequest)
  ))
_sym_db.RegisterMessage(ExtractRequest)

ExtractReply = _reflection.GeneratedProtocolMessageType('ExtractReply', (_message.Message,), dict(
  DESCRIPTOR = _EXTRACTREPLY,
  __module__ = 'text_extract_pb2'
  # @@protoc_insertion_point(class_scope:text_extract.ExtractReply)
  ))
_sym_db.RegisterMessage(ExtractReply)



_TEXTEXTRACTOR = _descriptor.ServiceDescriptor(
  name='TextExtractor',
  full_name='text_extract.TextExtractor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=153,
  serialized_end=239,
  methods=[
  _descriptor.MethodDescriptor(
    name='extract',
    full_name='text_extract.TextExtractor.extract',
    index=0,
    containing_service=None,
    input_type=_EXTRACTREQUEST,
    output_type=_EXTRACTREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TEXTEXTRACTOR)

DESCRIPTOR.services_by_name['TextExtractor'] = _TEXTEXTRACTOR

# @@protoc_insertion_point(module_scope)
